// Author 		: F. de la Parra
// Date			: March, 2019
// Description  : This JavaFX application implements a series of scenarios
//				  where components trigger events and event handling methods
//				  implement GUI answers in response to those events. The 
//				  application's presentation layer is built with the Scene
//				  Builder tool and stored in file "layout.fxml". This tool
//				  also generates the skeleton of a "Controller.java" class
//				  which contains the event handler methods and it is invoked
//				  in file layout.fxml".
// Version      : 1.0

import javafx.application.Application;
import javafx.fxml.FXMLLoader;
import javafx.stage.Stage;
import javafx.scene.Scene;
import javafx.scene.layout.AnchorPane;


public class JavaFXEvents extends Application {
	@Override
	public void start(Stage primaryStage) {
		try {
			// Load GUI components object-tree into AnchorPane root container.
			AnchorPane root = (AnchorPane)FXMLLoader.load(getClass().getResource("layout.fxml"));
			
			// Create javaFX scene object contained rooted object-tree above.
			Scene scene = new Scene(root,600,400);
			
			// Apply styles for presentation of GUI components in scene object.
			scene.getStylesheets().add(getClass().getResource("application.css").toExternalForm());
			
			// Load scene object onto a stage object.
			primaryStage.setScene(scene);
			
			// Display stage object.
			primaryStage.show();
			
		} catch(Exception e) {
			e.printStackTrace();
		}
	}
	
	public static void main(String[] args) {
		launch(args);
	}
}
